import { env } from "@/utils/env";
import * as schema from "@/server/db/schema";

// Wrap database initialization in try-catch to handle native binding errors
let sqlite;
let db;

try {
  // Dynamically import better-sqlite3 to handle binding errors more gracefully
  const Database = require("better-sqlite3");
  sqlite = new Database(env.DB_PATH);
  
  const { drizzle } = require("drizzle-orm/better-sqlite3");
  db = drizzle(sqlite, { schema });
} catch (error) {
  console.error("Failed to initialize database:", error);
  
  // Create mock database for SSR to prevent crashes
  db = {
    query: () => [],
    select: () => ({ get: () => null, all: () => [] }),
    insert: () => ({ values: () => ({ returning: () => [] }) }),
    update: () => ({ set: () => ({ where: () => [] }) }),
    delete: () => ({ where: () => [] }),
  };
}

export { db };
